from setuptools import setup

setup(
    name="iflow-mcp_ahrentlov-appledeepdoc-mcp",
    version="0.1.3",
    description="MCP server for accessing Apple's hidden Xcode documentation",
    packages=[""],
    package_data={"": ["*.py", "docs/*.py", "evolution/*.py", "repos/*.py", "wwdc/*.py", "design/*.py", "suggestions/*.py"]},
    include_package_data=True,
    python_requires=">=3.10",
    install_requires=[
        "fastmcp>=0.1.0",
    ],
    entry_points={
        "console_scripts": [
            "appledeepdoc-mcp=main:main",
        ],
    },
)